Struct amazon_sp_vendor_shipments::models::dimensions::Dimensions
source · [−]pub struct Dimensions {
pub length: String,
pub width: String,
pub height: String,
pub unit_of_measure: UnitOfMeasure,
}Expand description
Dimensions : Physical dimensional measurements of a container.
Fields
length: StringA decimal number with no loss of precision. Useful when precision loss is unacceptable, as with currencies. Follows RFC7159 for number representation.
Pattern : ^-?(0|([1-9]\\d*))(\\.\\d+)?([eE][+-]?\\d+)?$.
width: StringA decimal number with no loss of precision. Useful when precision loss is unacceptable, as with currencies. Follows RFC7159 for number representation.
Pattern : ^-?(0|([1-9]\\d*))(\\.\\d+)?([eE][+-]?\\d+)?$.
height: StringA decimal number with no loss of precision. Useful when precision loss is unacceptable, as with currencies. Follows RFC7159 for number representation.
Pattern : ^-?(0|([1-9]\\d*))(\\.\\d+)?([eE][+-]?\\d+)?$.
unit_of_measure: UnitOfMeasureThe unit of measure for dimensions.
Implementations
sourceimpl Dimensions
impl Dimensions
sourcepub fn new(
length: String,
width: String,
height: String,
unit_of_measure: UnitOfMeasure
) -> Dimensions
pub fn new(
length: String,
width: String,
height: String,
unit_of_measure: UnitOfMeasure
) -> Dimensions
Physical dimensional measurements of a container.